@@ -16,6 +16,9 @@ EXTENSIONS = {
     'cc': {'text', 'c++'},
     'cu': {'text', 'cuda'},
     'cfg': {'text'},
+    'clj': {'text', 'clojure'},
+    'cljc': {'text', 'clojure'},
+    'cljs': {'text', 'clojure', 'clojurescript'},
     'cmake': {'text', 'cmake'},
     'cnf': {'text'},
     'coffee': {'text', 'coffee'},
@@ -31,6 +34,7 @@ EXTENSIONS = {
     'def': {'text', 'def'},
     'dtd': {'text', 'dtd'},
     'ear': {'binary', 'zip', 'jar'},
+    'edn': {'text', 'clojure', 'edn'},
     'ejs': {'text', 'ejs'},
     'eot': {'binary', 'eot'},
     'eps': {'binary', 'eps'},
